=======
whereis
=======


.. image:: https://img.shields.io/pypi/v/whereis.svg
        :target: https://pypi.python.org/pypi/whereis

.. image:: https://img.shields.io/travis/draperjames/whereis.svg
        :target: https://travis-ci.org/draperjames/whereis

.. image:: https://readthedocs.org/projects/whereis/badge/?version=latest
        :target: https://whereis.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Platform independent whereis.


* Free software: MIT license
* Documentation: https://whereis.readthedocs.io.


Features
--------

* TODO
